package com.muyu.rule.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.rule.service.RuleService;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import rule.domain.Rule;

import java.util.List;

/**
 * @ClassName RuleController
 * @Description 规则控制层
 * @Author Chen
 * @Date 2024/8/20 14:22
 */
@RestController
@RequestMapping("/rule")
public class RuleController {
    @Autowired
    private RuleService ruleService;

    /**
     * 规则列表
     *
     * @return
     */
    @PostMapping("/list")
    @Operation(summary = "查看规则", description = "规则")
    public Result<List<Rule>> select(@RequestBody Rule rule) {
        return Result.success(ruleService.select(rule));
    }

    /**
     * 规则修改
     *
     * @return
     */
    @PutMapping("/update")
    public Result update(@RequestBody Rule rule) {
        return Result.success(ruleService.updateById(rule));
    }

    /**
     * 规则删除
     *
     * @return
     */
    @DeleteMapping("/delete")
    public Result delete(@RequestParam Integer id) {
        return Result.success(ruleService.removeById(id));
    }

    /**
     * 规则添加
     *
     * @return
     */
    @PostMapping("/insert")
    public Result insert(@RequestBody Rule rule) {
        return Result.success(ruleService.save(rule));
    }


}
